from django.db import models
from phonenumber_field.modelfields import PhoneNumberField
from django.core.validators import FileExtensionValidator

import uuid

def unique_resume_filename(instance, filename):
    ext = filename.split('.')[-1]
    # generate a unique identifier using UUID
    # str(instance.identifier)
    unique_id = str(instance.identifier)
    filename = f"{instance.name.replace(' ', '_')}_resume_{unique_id}.{ext}"
    return f"resumes/{filename}"


class HiringApplication(models.Model):
    identifier = models.UUIDField(unique=True, default=uuid.uuid4, editable=False)
    name=models.CharField(max_length=200)
    email=models.EmailField()
    phoneNumber=PhoneNumberField(help_text="enter mobile number with valid country code (ex: +91)")
    city= models.CharField(max_length=100)
    address= models.CharField(max_length=300)
    degree= models.CharField(max_length=200)
    post= models.CharField(max_length=300)
    resume=models.FileField(
        upload_to=unique_resume_filename,
        help_text="File formats must be in (.pdf,.docx,.doc)",
        validators=[
            FileExtensionValidator(
                allowed_extensions=[
                    "pdf",
                    "docx",
                    "doc",
                ]
            )
            
        ],

        
    )
    
    def __str__(self):
        return self.name
    